pub struct EmbeddingModelRequest<M: EmbeddingModel> {
pub model: M,
/* private fields */
}Expand description
Options for embedding generation requests to be used by embed.
Fields
model: MThe embedding model to use for generating embeddings.
Implementations
Sourceimpl<M: EmbeddingModel> EmbeddingModelRequest<M>
impl<M: EmbeddingModel> EmbeddingModelRequest<M>
Sourcepub fn builder() -> EmbeddingModelRequestBuilder<M>
pub fn builder() -> EmbeddingModelRequestBuilder<M>
Creates a new builder for constructing an EmbeddingModelRequest.
This method initiates the type-state builder pattern, starting with the
ModelStage where you must specify the embedding model.
Sourcepub async fn embed(&self) -> Result<EmbeddingModelResponse>
pub async fn embed(&self) -> Result<EmbeddingModelResponse>
Generates embeddings for the input text.
Returns
A Result containing a vector of embedding vectors, where each embedding is a vector of floats, or an error if the embedding request fails.